@@ -275,9 +275,7 @@ def detect_face(img, detector_backend = 'opencv', grayscale = False, enforce_det
 				raise ValueError("Face could not be detected. Please confirm that the picture is a face photo or consider to set enforce_detection param to False.") 
 		
 	elif detector_backend == 'mtcnn':
-		
-		from mtcnn import MTCNN #this is not a must library within deepface
-		
+		from mtcnn import MTCNN #0.1.0
 		mtcnn_detector = MTCNN()
 		
 		detections = mtcnn_detector.detect_faces(img)
@@ -432,7 +430,8 @@ def align_face(img, detector_backend = 'opencv'):
 		return img #return img anyway
 	
 	elif detector_backend == 'mtcnn':
-		from mtcnn import MTCNN
+		
+		from mtcnn import MTCNN #0.1.0
 		mtcnn_detector = MTCNN()
 		detections = mtcnn_detector.detect_faces(img)
 		
